@@ -1043,7 +1043,7 @@ ENABLE_EVENTS (_id, X_CLIENT_WINDOW_EVENTS)
     _drawn_frame_decor = [self get_xp_frame_class] & XP_FRAME_CLASS_DECOR_MASK;
     
     draw_frame (_screen->_id, _frame_id, or, ir, [self get_xp_frame_class],
-                frame_attr, (CFStringRef) [self title]);
+                frame_attr, (CFStringRef) [self title], _shortcut_index);
 
     _decorated = YES;
     _pending_decorate = NO;
@@ -2139,7 +2139,7 @@ ENABLE_EVENTS (_id, X_CLIENT_WINDOW_EVENTS)
     if (wid == XP_NULL_NATIVE_WINDOW_ID)
         return;
 
-    title_c = strdup([_title UTF8String]);
+    title_c = strdup([[self title] UTF8String]);
     assert(title_c);
 
     err = qwm_dock_minimize_item_with_title_async (wid, title_c);
@@ -2652,7 +2652,7 @@ decode_size_hints (XSizeHints *hints, int base[2], int min[2],
     if (_title != nil)
         return [NSString stringWithFormat:@"{x-window %@}", _title];
     else
-        return [NSString stringWithFormat:@"{x-window 0x%x}", _id];
+        return [NSString stringWithFormat:@"{x-window 0x%lx}", _id];
 }
 
 - (X11Rect) intended_frame
